diff --git a/ARCHITECTURE.md b/ARCHITECTURE.md
index f1713242422f..7ac2edc0cfa9 100644
--- a/ARCHITECTURE.md
+++ b/ARCHITECTURE.md
@@ -88,11 +88,11 @@ Of course, this will only take us so far. In the future we plan on caching queri
Here is an overview of the crates included in the project:
@@ -168,7 +168,6 @@ Update instructions:
| re_protos | Rerun remote store gRPC API types |
| re_query | Querying data in the re_chunk_store |
| re_types | The built-in Rerun data types, component types, and archetypes. |
-| re_types_blueprint | The core traits and types that power Rerun's Blueprint sub-system. |
### Low-level store
diff --git a/Cargo.lock b/Cargo.lock
index 4a5eee7bfb59..8f3a411f3fb9 100644
--- a/Cargo.lock
+++ b/Cargo.lock
@@ -5698,7 +5698,6 @@ dependencies = [
"re_log_types",
"re_tracing",
"re_types",
- "re_types_blueprint",
"re_types_core",
"re_ui",
"re_viewer_context",
@@ -6295,7 +6294,6 @@ dependencies = [
"re_log_types",
"re_tracing",
"re_types",
- "re_types_blueprint",
"re_types_core",
"re_ui",
"re_view",
@@ -6423,18 +6421,6 @@ dependencies = [
"uuid",
]
-[[package]]
-name = "re_types_blueprint"
-version = "0.21.0-alpha.1+dev"
-dependencies = [
- "arrow",
- "once_cell",
- "re_arrow2",
- "re_tracing",
- "re_types",
- "re_types_core",
-]
-
[[package]]
name = "re_types_builder"
version = "0.21.0-alpha.1+dev"
@@ -6828,7 +6814,6 @@ dependencies = [
"re_time_panel",
"re_tracing",
"re_types",
- "re_types_blueprint",
"re_types_core",
"re_ui",
"re_video",
@@ -6932,7 +6917,6 @@ dependencies = [
"re_renderer",
"re_tracing",
"re_types",
- "re_types_blueprint",
"re_ui",
"re_view",
"re_viewer_context",
@@ -6957,7 +6941,6 @@ dependencies = [
"re_log_types",
"re_tracing",
"re_types",
- "re_types_blueprint",
"re_types_core",
"re_ui",
"re_viewer_context",
diff --git a/Cargo.toml b/Cargo.toml
index 7eacba039f5c..73d17d1b009f 100644
--- a/Cargo.toml
+++ b/Cargo.toml
@@ -61,7 +61,6 @@ re_log_types = { path = "crates/store/re_log_types", version = "=0.21.0-alpha.1"
re_query = { path = "crates/store/re_query", version = "=0.21.0-alpha.1", default-features = false }
re_sdk_comms = { path = "crates/store/re_sdk_comms", version = "=0.21.0-alpha.1", default-features = false }
re_types = { path = "crates/store/re_types", version = "=0.21.0-alpha.1", default-features = false }
-re_types_blueprint = { path = "crates/store/re_types_blueprint", version = "=0.21.0-alpha.1", default-features = false }
re_types_core = { path = "crates/store/re_types_core", version = "=0.21.0-alpha.1", default-features = false }
re_ws_comms = { path = "crates/store/re_ws_comms", version = "=0.21.0-alpha.1", default-features = false }
diff --git a/crates/store/re_types/definitions/rerun/blueprint/archetypes/container_blueprint.fbs b/crates/store/re_types/definitions/rerun/blueprint/archetypes/container_blueprint.fbs
index a1b95850a063..454ab1f93ff0 100644
--- a/crates/store/re_types/definitions/rerun/blueprint/archetypes/container_blueprint.fbs
+++ b/crates/store/re_types/definitions/rerun/blueprint/archetypes/container_blueprint.fbs
@@ -4,8 +4,7 @@ namespace rerun.blueprint.archetypes;
/// The description of a container.
table ContainerBlueprint (
- "attr.rerun.scope": "blueprint",
- "attr.rust.override_crate": "re_types_blueprint"
+ "attr.rerun.scope": "blueprint"
) {
// --- Required ---
diff --git a/crates/store/re_types/definitions/rerun/blueprint/archetypes/panel_blueprint.fbs b/crates/store/re_types/definitions/rerun/blueprint/archetypes/panel_blueprint.fbs
index 4fa6a08e5a2e..28660dc25330 100644
--- a/crates/store/re_types/definitions/rerun/blueprint/archetypes/panel_blueprint.fbs
+++ b/crates/store/re_types/definitions/rerun/blueprint/archetypes/panel_blueprint.fbs
@@ -5,12 +5,13 @@ namespace rerun.blueprint.archetypes;
/// Shared state for the 3 collapsible panels.
table PanelBlueprint (
"attr.rerun.scope": "blueprint",
- "attr.rust.derive": "Default",
- "attr.rust.override_crate": "re_types_blueprint"
+ "attr.rust.derive": "Default"
) {
// --- Required ---
// --- Optional ---
+
+ /// Current state of the panels.
state: rerun.blueprint.components.PanelState ("attr.rerun.component_optional", nullable, order: 1000);
// TODO(jleibs): Add a float to track how expanded the panel is.
diff --git a/crates/store/re_types/definitions/rerun/blueprint/archetypes/viewport_blueprint.fbs b/crates/store/re_types/definitions/rerun/blueprint/archetypes/viewport_blueprint.fbs
index 8b1d46d6e9a1..dc0cfff65e0f 100644
--- a/crates/store/re_types/definitions/rerun/blueprint/archetypes/viewport_blueprint.fbs
+++ b/crates/store/re_types/definitions/rerun/blueprint/archetypes/viewport_blueprint.fbs
@@ -5,8 +5,7 @@ namespace rerun.blueprint.archetypes;
/// The top-level description of the viewport.
table ViewportBlueprint (
"attr.rerun.scope": "blueprint",
- "attr.rust.derive": "Default",
- "attr.rust.override_crate": "re_types_blueprint"
+ "attr.rust.derive": "Default"
) {
// --- Required ---
diff --git a/crates/store/re_types/definitions/rerun/blueprint/components/auto_layout.fbs b/crates/store/re_types/definitions/rerun/blueprint/components/auto_layout.fbs
index ebe3e7a437e6..025913652bd1 100644
--- a/crates/store/re_types/definitions/rerun/blueprint/components/auto_layout.fbs
+++ b/crates/store/re_types/definitions/rerun/blueprint/components/auto_layout.fbs
@@ -6,10 +6,9 @@ namespace rerun.blueprint.components;
/// Whether the viewport layout is determined automatically.
struct AutoLayout (
"attr.arrow.transparent",
- "attr.rerun.scope": "blueprint",
"attr.python.aliases": "bool",
+ "attr.rerun.scope": "blueprint",
"attr.rust.derive": "Copy",
- "attr.rust.override_crate": "re_types_blueprint",
"attr.rust.repr": "transparent",
"attr.rust.tuple_struct"
) {
diff --git a/crates/store/re_types/definitions/rerun/blueprint/components/auto_views.fbs b/crates/store/re_types/definitions/rerun/blueprint/components/auto_views.fbs
index ce4a452dd4c3..ad17a39f9225 100644
--- a/crates/store/re_types/definitions/rerun/blueprint/components/auto_views.fbs
+++ b/crates/store/re_types/definitions/rerun/blueprint/components/auto_views.fbs
@@ -7,7 +7,6 @@ struct AutoViews (
"attr.rerun.scope": "blueprint",
"attr.python.aliases": "bool",
"attr.rust.derive": "Copy, Default, PartialEq, Eq, PartialOrd, Ord",
- "attr.rust.override_crate": "re_types_blueprint",
"attr.rust.repr": "transparent",
"attr.rust.tuple_struct"
) {
diff --git a/crates/store/re_types/definitions/rerun/blueprint/components/container_kind.fbs b/crates/store/re_types/definitions/rerun/blueprint/components/container_kind.fbs
index d4339e9221a7..043da7f771cf 100644
--- a/crates/store/re_types/definitions/rerun/blueprint/components/container_kind.fbs
+++ b/crates/store/re_types/definitions/rerun/blueprint/components/container_kind.fbs
@@ -3,8 +3,7 @@ namespace rerun.blueprint.components;
/// The kind of a blueprint container (tabs, grid, …).
enum ContainerKind: ubyte (
- "attr.rerun.scope": "blueprint",
- "attr.rust.override_crate": "re_types_blueprint"
+ "attr.rerun.scope": "blueprint"
) {
/// Invalid value. Won't show up in generated types.
Invalid = 0,
diff --git a/crates/store/re_types/definitions/rerun/blueprint/components/grid_columns.fbs b/crates/store/re_types/definitions/rerun/blueprint/components/grid_columns.fbs
index eed5b34e013e..16659fef59d0 100644
--- a/crates/store/re_types/definitions/rerun/blueprint/components/grid_columns.fbs
+++ b/crates/store/re_types/definitions/rerun/blueprint/components/grid_columns.fbs
@@ -5,8 +5,7 @@ namespace rerun.blueprint.components;
table GridColumns (
"attr.rerun.scope": "blueprint",
"attr.python.aliases": "int",
- "attr.rust.derive": "Default, PartialEq, Eq, PartialOrd, Ord",
- "attr.rust.override_crate": "re_types_blueprint"
+ "attr.rust.derive": "Default, PartialEq, Eq, PartialOrd, Ord"
) {
/// The number of columns.
columns: rerun.datatypes.UInt32 (order: 100);
diff --git a/crates/store/re_types/definitions/rerun/blueprint/components/root_container.fbs b/crates/store/re_types/definitions/rerun/blueprint/components/root_container.fbs
index ee6348f84cfe..2eb333c6f891 100644
--- a/crates/store/re_types/definitions/rerun/blueprint/components/root_container.fbs
+++ b/crates/store/re_types/definitions/rerun/blueprint/components/root_container.fbs
@@ -7,9 +7,7 @@ namespace rerun.blueprint.components;
table RootContainer (
"attr.rerun.scope": "blueprint",
"attr.python.aliases": "npt.NDArray[np.uint8], npt.ArrayLike, Sequence[int], bytes",
- "attr.rust.derive": "Default",
- "attr.rust.override_crate": "re_types_blueprint",
- "attr.rust.repr": "transparent"
+ "attr.rust.derive": "Default"
) {
/// `ContainerId` for the root.
id: rerun.datatypes.Uuid (order: 100);
diff --git a/crates/store/re_types/definitions/rerun/blueprint/components/view_maximized.fbs b/crates/store/re_types/definitions/rerun/blueprint/components/view_maximized.fbs
index 405e62cbcbc7..6bf29a4de998 100644
--- a/crates/store/re_types/definitions/rerun/blueprint/components/view_maximized.fbs
+++ b/crates/store/re_types/definitions/rerun/blueprint/components/view_maximized.fbs
@@ -4,9 +4,7 @@ namespace rerun.blueprint.components;
table ViewMaximized (
"attr.rerun.scope": "blueprint",
"attr.python.aliases": "npt.NDArray[np.uint8], npt.ArrayLike, Sequence[int], bytes",
- "attr.rust.derive": "Default",
- "attr.rust.override_crate": "re_types_blueprint",
- "attr.rust.repr": "transparent"
+ "attr.rust.derive": "Default"
) {
view_id: rerun.datatypes.Uuid (order: 100);
}
diff --git a/crates/store/re_types/definitions/rerun/blueprint/components/visualizer_overrides.fbs b/crates/store/re_types/definitions/rerun/blueprint/components/visualizer_overrides.fbs
index fedd2980d452..dc07e47ccb0a 100644
--- a/crates/store/re_types/definitions/rerun/blueprint/components/visualizer_overrides.fbs
+++ b/crates/store/re_types/definitions/rerun/blueprint/components/visualizer_overrides.fbs
@@ -17,8 +17,7 @@ table VisualizerOverrides (
"attr.python.array_aliases": "str",
"attr.rerun.scope": "blueprint",
"attr.rust.derive": "PartialEq, Eq, PartialOrd, Ord, Default",
- "attr.rust.repr": "transparent",
- "attr.rust.override_crate": "re_types_blueprint"
+ "attr.rust.repr": "transparent"
) {
/// Names of the visualizers that should be active.
visualizers: rerun.blueprint.datatypes.Utf8List (order: 100);
diff --git a/crates/store/re_types/definitions/rerun/blueprint/datatypes/utf8_list.fbs b/crates/store/re_types/definitions/rerun/blueprint/datatypes/utf8_list.fbs
index febfb90d4d2b..cf030552acfd 100644
--- a/crates/store/re_types/definitions/rerun/blueprint/datatypes/utf8_list.fbs
+++ b/crates/store/re_types/definitions/rerun/blueprint/datatypes/utf8_list.fbs
@@ -9,8 +9,7 @@ table Utf8List (
"attr.rerun.scope": "blueprint",
"attr.rust.derive": "PartialEq, Eq, PartialOrd, Ord, Default, Hash",
"attr.rust.repr": "transparent",
- "attr.rust.tuple_struct",
- "attr.rust.override_crate": "re_types_blueprint"
+ "attr.rust.tuple_struct"
) {
value: [string] (order: 100);
}
diff --git a/crates/store/re_types/src/blueprint/archetypes/.gitattributes b/crates/store/re_types/src/blueprint/archetypes/.gitattributes
index 1065a18b6415..e8331953aab0 100644
--- a/crates/store/re_types/src/blueprint/archetypes/.gitattributes
+++ b/crates/store/re_types/src/blueprint/archetypes/.gitattributes
@@ -2,6 +2,7 @@
.gitattributes linguist-generated=true
background.rs linguist-generated=true
+container_blueprint.rs linguist-generated=true
dataframe_query.rs linguist-generated=true
force_center.rs linguist-generated=true
force_collision_radius.rs linguist-generated=true
@@ -12,6 +13,7 @@ line_grid3d.rs linguist-generated=true
map_background.rs linguist-generated=true
map_zoom.rs linguist-generated=true
mod.rs linguist-generated=true
+panel_blueprint.rs linguist-generated=true
plot_legend.rs linguist-generated=true
scalar_axis.rs linguist-generated=true
tensor_scalar_mapping.rs linguist-generated=true
@@ -19,5 +21,6 @@ tensor_slice_selection.rs linguist-generated=true
tensor_view_fit.rs linguist-generated=true
view_blueprint.rs linguist-generated=true
view_contents.rs linguist-generated=true
+viewport_blueprint.rs linguist-generated=true
visible_time_ranges.rs linguist-generated=true
visual_bounds2d.rs linguist-generated=true
diff --git a/crates/store/re_types_blueprint/src/blueprint/archetypes/container_blueprint.rs b/crates/store/re_types/src/blueprint/archetypes/container_blueprint.rs
similarity index 100%
rename from crates/store/re_types_blueprint/src/blueprint/archetypes/container_blueprint.rs
rename to crates/store/re_types/src/blueprint/archetypes/container_blueprint.rs
diff --git a/crates/store/re_types/src/blueprint/archetypes/mod.rs b/crates/store/re_types/src/blueprint/archetypes/mod.rs
index 3590029048a5..c0b54d19a91d 100644
--- a/crates/store/re_types/src/blueprint/archetypes/mod.rs
+++ b/crates/store/re_types/src/blueprint/archetypes/mod.rs
@@ -1,6 +1,7 @@
// DO NOT EDIT! This file was auto-generated by crates/build/re_types_builder/src/codegen/rust/api.rs
mod background;
+mod container_blueprint;
mod dataframe_query;
mod force_center;
mod force_collision_radius;
@@ -10,6 +11,7 @@ mod force_position;
mod line_grid3d;
mod map_background;
mod map_zoom;
+mod panel_blueprint;
mod plot_legend;
mod scalar_axis;
mod tensor_scalar_mapping;
@@ -17,11 +19,13 @@ mod tensor_slice_selection;
mod tensor_view_fit;
mod view_blueprint;
mod view_contents;
+mod viewport_blueprint;
mod visible_time_ranges;
mod visible_time_ranges_ext;
mod visual_bounds2d;
pub use self::background::Background;
+pub use self::container_blueprint::ContainerBlueprint;
pub use self::dataframe_query::DataframeQuery;
pub use self::force_center::ForceCenter;
pub use self::force_collision_radius::ForceCollisionRadius;
@@ -31,6 +35,7 @@ pub use self::force_position::ForcePosition;
pub use self::line_grid3d::LineGrid3D;
pub use self::map_background::MapBackground;
pub use self::map_zoom::MapZoom;
+pub use self::panel_blueprint::PanelBlueprint;
pub use self::plot_legend::PlotLegend;
pub use self::scalar_axis::ScalarAxis;
pub use self::tensor_scalar_mapping::TensorScalarMapping;
@@ -38,5 +43,6 @@ pub use self::tensor_slice_selection::TensorSliceSelection;
pub use self::tensor_view_fit::TensorViewFit;
pub use self::view_blueprint::ViewBlueprint;
pub use self::view_contents::ViewContents;
+pub use self::viewport_blueprint::ViewportBlueprint;
pub use self::visible_time_ranges::VisibleTimeRanges;
pub use self::visual_bounds2d::VisualBounds2D;
diff --git a/crates/store/re_types_blueprint/src/blueprint/archetypes/panel_blueprint.rs b/crates/store/re_types/src/blueprint/archetypes/panel_blueprint.rs
similarity index 98%
rename from crates/store/re_types_blueprint/src/blueprint/archetypes/panel_blueprint.rs
rename to crates/store/re_types/src/blueprint/archetypes/panel_blueprint.rs
index 8197210161ae..7f55137e124f 100644
--- a/crates/store/re_types_blueprint/src/blueprint/archetypes/panel_blueprint.rs
+++ b/crates/store/re_types/src/blueprint/archetypes/panel_blueprint.rs
@@ -21,6 +21,7 @@ use ::re_types_core::{DeserializationError, DeserializationResult};
/// **Archetype**: Shared state for the 3 collapsible panels.
#[derive(Clone, Debug, Default)]
pub struct PanelBlueprint {
+ /// Current state of the panels.
pub state: Option,
}
@@ -166,6 +167,7 @@ impl PanelBlueprint {
Self { state: None }
}
+ /// Current state of the panels.
#[inline]
pub fn with_state(
mut self,
diff --git a/crates/store/re_types_blueprint/src/blueprint/archetypes/viewport_blueprint.rs b/crates/store/re_types/src/blueprint/archetypes/viewport_blueprint.rs
similarity index 100%
rename from crates/store/re_types_blueprint/src/blueprint/archetypes/viewport_blueprint.rs
rename to crates/store/re_types/src/blueprint/archetypes/viewport_blueprint.rs
diff --git a/crates/store/re_types/src/blueprint/components/.gitattributes b/crates/store/re_types/src/blueprint/components/.gitattributes
index 8ad1b4e0df36..26c669440aaf 100644
--- a/crates/store/re_types/src/blueprint/components/.gitattributes
+++ b/crates/store/re_types/src/blueprint/components/.gitattributes
@@ -3,9 +3,12 @@
.gitattributes linguist-generated=true
active_tab.rs linguist-generated=true
apply_latest_at.rs linguist-generated=true
+auto_layout.rs linguist-generated=true
+auto_views.rs linguist-generated=true
background_kind.rs linguist-generated=true
column_share.rs linguist-generated=true
component_column_selector.rs linguist-generated=true
+container_kind.rs linguist-generated=true
corner2d.rs linguist-generated=true
enabled.rs linguist-generated=true
filter_by_range.rs linguist-generated=true
@@ -13,6 +16,7 @@ filter_is_not_null.rs linguist-generated=true
force_distance.rs linguist-generated=true
force_iterations.rs linguist-generated=true
force_strength.rs linguist-generated=true
+grid_columns.rs linguist-generated=true
grid_spacing.rs linguist-generated=true
included_content.rs linguist-generated=true
interactive.rs linguist-generated=true
@@ -22,15 +26,18 @@ mod.rs linguist-generated=true
near_clip_plane.rs linguist-generated=true
panel_state.rs linguist-generated=true
query_expression.rs linguist-generated=true
+root_container.rs linguist-generated=true
row_share.rs linguist-generated=true
selected_columns.rs linguist-generated=true
tensor_dimension_index_slider.rs linguist-generated=true
timeline_name.rs linguist-generated=true
view_class.rs linguist-generated=true
view_fit.rs linguist-generated=true
+view_maximized.rs linguist-generated=true
view_origin.rs linguist-generated=true
viewer_recommendation_hash.rs linguist-generated=true
visible.rs linguist-generated=true
visible_time_range.rs linguist-generated=true
visual_bounds2d.rs linguist-generated=true
+visualizer_overrides.rs linguist-generated=true
zoom_level.rs linguist-generated=true
diff --git a/crates/store/re_types_blueprint/src/blueprint/components/auto_layout.rs b/crates/store/re_types/src/blueprint/components/auto_layout.rs
similarity index 100%
rename from crates/store/re_types_blueprint/src/blueprint/components/auto_layout.rs
rename to crates/store/re_types/src/blueprint/components/auto_layout.rs
diff --git a/crates/store/re_types_blueprint/src/blueprint/components/auto_layout_ext.rs b/crates/store/re_types/src/blueprint/components/auto_layout_ext.rs
similarity index 80%
rename from crates/store/re_types_blueprint/src/blueprint/components/auto_layout_ext.rs
rename to crates/store/re_types/src/blueprint/components/auto_layout_ext.rs
index 4113abafc344..79573e7901fe 100644
--- a/crates/store/re_types_blueprint/src/blueprint/components/auto_layout_ext.rs
+++ b/crates/store/re_types/src/blueprint/components/auto_layout_ext.rs
@@ -1,4 +1,4 @@
-use re_types::datatypes::Bool;
+use crate::datatypes::Bool;
use super::AutoLayout;
diff --git a/crates/store/re_types_blueprint/src/blueprint/components/auto_views.rs b/crates/store/re_types/src/blueprint/components/auto_views.rs
similarity index 100%
rename from crates/store/re_types_blueprint/src/blueprint/components/auto_views.rs
rename to crates/store/re_types/src/blueprint/components/auto_views.rs
diff --git a/crates/store/re_types_blueprint/src/blueprint/components/container_kind.rs b/crates/store/re_types/src/blueprint/components/container_kind.rs
similarity index 100%
rename from crates/store/re_types_blueprint/src/blueprint/components/container_kind.rs
rename to crates/store/re_types/src/blueprint/components/container_kind.rs
diff --git a/crates/store/re_types_blueprint/src/blueprint/components/grid_columns.rs b/crates/store/re_types/src/blueprint/components/grid_columns.rs
similarity index 100%
rename from crates/store/re_types_blueprint/src/blueprint/components/grid_columns.rs
rename to crates/store/re_types/src/blueprint/components/grid_columns.rs
diff --git a/crates/store/re_types/src/blueprint/components/mod.rs b/crates/store/re_types/src/blueprint/components/mod.rs
index 78723bc794d0..7933d51c393a 100644
--- a/crates/store/re_types/src/blueprint/components/mod.rs
+++ b/crates/store/re_types/src/blueprint/components/mod.rs
@@ -2,10 +2,14 @@
mod active_tab;
mod apply_latest_at;
+mod auto_layout;
+mod auto_layout_ext;
+mod auto_views;
mod background_kind;
mod column_share;
mod component_column_selector;
mod component_column_selector_ext;
+mod container_kind;
mod corner2d;
mod corner2d_ext;
mod enabled;
@@ -17,6 +21,7 @@ mod filter_is_not_null_ext;
mod force_distance;
mod force_iterations;
mod force_strength;
+mod grid_columns;
mod grid_spacing;
mod grid_spacing_ext;
mod included_content;
@@ -29,6 +34,7 @@ mod near_clip_plane_ext;
mod panel_state;
mod panel_state_ext;
mod query_expression;
+mod root_container;
mod row_share;
mod selected_columns;
mod tensor_dimension_index_slider;
@@ -38,6 +44,7 @@ mod timeline_name_ext;
mod view_class;
mod view_class_ext;
mod view_fit;
+mod view_maximized;
mod view_origin;
mod view_origin_ext;
mod viewer_recommendation_hash;
@@ -47,13 +54,17 @@ mod visible_ext;
mod visible_time_range;
mod visual_bounds2d;
mod visual_bounds2d_ext;
+mod visualizer_overrides;
mod zoom_level;
pub use self::active_tab::ActiveTab;
pub use self::apply_latest_at::ApplyLatestAt;
+pub use self::auto_layout::AutoLayout;
+pub use self::auto_views::AutoViews;
pub use self::background_kind::BackgroundKind;
pub use self::column_share::ColumnShare;
pub use self::component_column_selector::ComponentColumnSelector;
+pub use self::container_kind::ContainerKind;
pub use self::corner2d::Corner2D;
pub use self::enabled::Enabled;
pub use self::filter_by_range::FilterByRange;
@@ -61,6 +72,7 @@ pub use self::filter_is_not_null::FilterIsNotNull;
pub use self::force_distance::ForceDistance;
pub use self::force_iterations::ForceIterations;
pub use self::force_strength::ForceStrength;
+pub use self::grid_columns::GridColumns;
pub use self::grid_spacing::GridSpacing;
pub use self::included_content::IncludedContent;
pub use self::interactive::Interactive;
@@ -69,15 +81,18 @@ pub use self::map_provider::MapProvider;
pub use self::near_clip_plane::NearClipPlane;
pub use self::panel_state::PanelState;
pub use self::query_expression::QueryExpression;
+pub use self::root_container::RootContainer;
pub use self::row_share::RowShare;
pub use self::selected_columns::SelectedColumns;
pub use self::tensor_dimension_index_slider::TensorDimensionIndexSlider;
pub use self::timeline_name::TimelineName;
pub use self::view_class::ViewClass;
pub use self::view_fit::ViewFit;
+pub use self::view_maximized::ViewMaximized;
pub use self::view_origin::ViewOrigin;
pub use self::viewer_recommendation_hash::ViewerRecommendationHash;
pub use self::visible::Visible;
pub use self::visible_time_range::VisibleTimeRange;
pub use self::visual_bounds2d::VisualBounds2D;
+pub use self::visualizer_overrides::VisualizerOverrides;
pub use self::zoom_level::ZoomLevel;
diff --git a/crates/store/re_types_blueprint/src/blueprint/components/root_container.rs b/crates/store/re_types/src/blueprint/components/root_container.rs
similarity index 99%
rename from crates/store/re_types_blueprint/src/blueprint/components/root_container.rs
rename to crates/store/re_types/src/blueprint/components/root_container.rs
index 9cfc9017f5d9..be4161f2de22 100644
--- a/crates/store/re_types_blueprint/src/blueprint/components/root_container.rs
+++ b/crates/store/re_types/src/blueprint/components/root_container.rs
@@ -20,7 +20,6 @@ use ::re_types_core::{DeserializationError, DeserializationResult};
/// **Component**: The container that sits at the root of a viewport.
#[derive(Clone, Debug, Default)]
-#[repr(transparent)]
pub struct RootContainer(
/// `ContainerId` for the root.
pub crate::datatypes::Uuid,
diff --git a/crates/store/re_types_blueprint/src/blueprint/components/view_maximized.rs b/crates/store/re_types/src/blueprint/components/view_maximized.rs
similarity index 99%
rename from crates/store/re_types_blueprint/src/blueprint/components/view_maximized.rs
rename to crates/store/re_types/src/blueprint/components/view_maximized.rs
index 27214db2194d..013b81cebc55 100644
--- a/crates/store/re_types_blueprint/src/blueprint/components/view_maximized.rs
+++ b/crates/store/re_types/src/blueprint/components/view_maximized.rs
@@ -20,7 +20,6 @@ use ::re_types_core::{DeserializationError, DeserializationResult};
/// **Component**: Whether a view is maximized.
#[derive(Clone, Debug, Default)]
-#[repr(transparent)]
pub struct ViewMaximized(pub crate::datatypes::Uuid);
impl ::re_types_core::Component for ViewMaximized {
diff --git a/crates/store/re_types_blueprint/src/blueprint/components/visualizer_overrides.rs b/crates/store/re_types/src/blueprint/components/visualizer_overrides.rs
similarity index 100%
rename from crates/store/re_types_blueprint/src/blueprint/components/visualizer_overrides.rs
rename to crates/store/re_types/src/blueprint/components/visualizer_overrides.rs
diff --git a/crates/store/re_types/src/blueprint/datatypes/.gitattributes b/crates/store/re_types/src/blueprint/datatypes/.gitattributes
index a5c2c2463632..3bf07cdc7a4b 100644
--- a/crates/store/re_types/src/blueprint/datatypes/.gitattributes
+++ b/crates/store/re_types/src/blueprint/datatypes/.gitattributes
@@ -7,3 +7,4 @@ filter_is_not_null.rs linguist-generated=true
mod.rs linguist-generated=true
selected_columns.rs linguist-generated=true
tensor_dimension_index_slider.rs linguist-generated=true
+utf8list.rs linguist-generated=true
diff --git a/crates/store/re_types/src/blueprint/datatypes/mod.rs b/crates/store/re_types/src/blueprint/datatypes/mod.rs
index b60da1620294..3998c09c31b9 100644
--- a/crates/store/re_types/src/blueprint/datatypes/mod.rs
+++ b/crates/store/re_types/src/blueprint/datatypes/mod.rs
@@ -6,9 +6,12 @@ mod filter_by_range;
mod filter_is_not_null;
mod selected_columns;
mod tensor_dimension_index_slider;
+mod utf8list;
+mod utf8list_ext;
pub use self::component_column_selector::ComponentColumnSelector;
pub use self::filter_by_range::FilterByRange;
pub use self::filter_is_not_null::FilterIsNotNull;
pub use self::selected_columns::SelectedColumns;
pub use self::tensor_dimension_index_slider::TensorDimensionIndexSlider;
+pub use self::utf8list::Utf8List;
diff --git a/crates/store/re_types_blueprint/src/blueprint/datatypes/utf8list.rs b/crates/store/re_types/src/blueprint/datatypes/utf8list.rs
similarity index 100%
rename from crates/store/re_types_blueprint/src/blueprint/datatypes/utf8list.rs
rename to crates/store/re_types/src/blueprint/datatypes/utf8list.rs
diff --git a/crates/store/re_types_blueprint/src/blueprint/datatypes/utf8list_ext.rs b/crates/store/re_types/src/blueprint/datatypes/utf8list_ext.rs
similarity index 100%
rename from crates/store/re_types_blueprint/src/blueprint/datatypes/utf8list_ext.rs
rename to crates/store/re_types/src/blueprint/datatypes/utf8list_ext.rs
diff --git a/crates/store/re_types_blueprint/.gitattributes b/crates/store/re_types_blueprint/.gitattributes
deleted file mode 100644
index 60dfe558e9de..000000000000
--- a/crates/store/re_types_blueprint/.gitattributes
+++ /dev/null
@@ -1,129 +0,0 @@
-# DO NOT EDIT! This file is generated by crates/build/re_types_builder/src/lib.rs
-
-.gitattributes linguist-generated=true
-src/archetypes/annotation_context.rs linguist-generated=true
-src/archetypes/arrows3d.rs linguist-generated=true
-src/archetypes/asset3d.rs linguist-generated=true
-src/archetypes/bar_chart.rs linguist-generated=true
-src/archetypes/boxes2d.rs linguist-generated=true
-src/archetypes/boxes3d.rs linguist-generated=true
-src/archetypes/clear.rs linguist-generated=true
-src/archetypes/depth_image.rs linguist-generated=true
-src/archetypes/disconnected_space.rs linguist-generated=true
-src/archetypes/image.rs linguist-generated=true
-src/archetypes/line_strips2d.rs linguist-generated=true
-src/archetypes/line_strips3d.rs linguist-generated=true
-src/archetypes/mesh3d.rs linguist-generated=true
-src/archetypes/mod.rs linguist-generated=true
-src/archetypes/pinhole.rs linguist-generated=true
-src/archetypes/points2d.rs linguist-generated=true
-src/archetypes/points3d.rs linguist-generated=true
-src/archetypes/segmentation_image.rs linguist-generated=true
-src/archetypes/tensor.rs linguist-generated=true
-src/archetypes/text_document.rs linguist-generated=true
-src/archetypes/text_log.rs linguist-generated=true
-src/archetypes/time_series_scalar.rs linguist-generated=true
-src/archetypes/transform3d.rs linguist-generated=true
-src/archetypes/view_coordinates.rs linguist-generated=true
-src/components/annotation_context.rs linguist-generated=true
-src/components/blob.rs linguist-generated=true
-src/components/class_id.rs linguist-generated=true
-src/components/clear_is_recursive.rs linguist-generated=true
-src/components/color.rs linguist-generated=true
-src/components/depth_meter.rs linguist-generated=true
-src/components/disconnected_space.rs linguist-generated=true
-src/components/draw_order.rs linguist-generated=true
-src/components/half_size2d.rs linguist-generated=true
-src/components/half_size3d.rs linguist-generated=true
-src/components/instance_key.rs linguist-generated=true
-src/components/keypoint_id.rs linguist-generated=true
-src/components/line_strip2d.rs linguist-generated=true
-src/components/line_strip3d.rs linguist-generated=true
-src/components/material.rs linguist-generated=true
-src/components/media_type.rs linguist-generated=true
-src/components/mesh_properties.rs linguist-generated=true
-src/components/mod.rs linguist-generated=true
-src/components/out_of_tree_transform3d.rs linguist-generated=true
-src/components/pinhole_projection.rs linguist-generated=true
-src/components/position2d.rs linguist-generated=true
-src/components/position3d.rs linguist-generated=true
-src/components/radius.rs linguist-generated=true
-src/components/resolution.rs linguist-generated=true
-src/components/rotation3d.rs linguist-generated=true
-src/components/scalar.rs linguist-generated=true
-src/components/scalar_scattering.rs linguist-generated=true
-src/components/tensor_data.rs linguist-generated=true
-src/components/text.rs linguist-generated=true
-src/components/text_log_level.rs linguist-generated=true
-src/components/transform3d.rs linguist-generated=true
-src/components/vector3d.rs linguist-generated=true
-src/components/view_coordinates.rs linguist-generated=true
-src/datatypes/angle.rs linguist-generated=true
-src/datatypes/annotation_info.rs linguist-generated=true
-src/datatypes/class_description.rs linguist-generated=true
-src/datatypes/class_description_map_elem.rs linguist-generated=true
-src/datatypes/class_id.rs linguist-generated=true
-src/datatypes/float32.rs linguist-generated=true
-src/datatypes/keypoint_id.rs linguist-generated=true
-src/datatypes/keypoint_pair.rs linguist-generated=true
-src/datatypes/mat3x3.rs linguist-generated=true
-src/datatypes/mat4x4.rs linguist-generated=true
-src/datatypes/material.rs linguist-generated=true
-src/datatypes/mesh_properties.rs linguist-generated=true
-src/datatypes/mod.rs linguist-generated=true
-src/datatypes/quaternion.rs linguist-generated=true
-src/datatypes/rgba32.rs linguist-generated=true
-src/datatypes/rotation3d.rs linguist-generated=true
-src/datatypes/rotation_axis_angle.rs linguist-generated=true
-src/datatypes/scale3d.rs linguist-generated=true
-src/datatypes/tensor_buffer.rs linguist-generated=true
-src/datatypes/tensor_data.rs linguist-generated=true
-src/datatypes/tensor_dimension.rs linguist-generated=true
-src/datatypes/transform3d.rs linguist-generated=true
-src/datatypes/translation_and_mat3x3.rs linguist-generated=true
-src/datatypes/translation_rotation_scale3d.rs linguist-generated=true
-src/datatypes/utf8.rs linguist-generated=true
-src/datatypes/uvec2d.rs linguist-generated=true
-src/datatypes/uvec3d.rs linguist-generated=true
-src/datatypes/uvec4d.rs linguist-generated=true
-src/datatypes/vec2d.rs linguist-generated=true
-src/datatypes/vec3d.rs linguist-generated=true
-src/datatypes/vec4d.rs linguist-generated=true
-src/testing/archetypes/affix_fuzzer1.rs linguist-generated=true
-src/testing/archetypes/affix_fuzzer2.rs linguist-generated=true
-src/testing/archetypes/affix_fuzzer3.rs linguist-generated=true
-src/testing/archetypes/affix_fuzzer4.rs linguist-generated=true
-src/testing/archetypes/mod.rs linguist-generated=true
-src/testing/components/affix_fuzzer1.rs linguist-generated=true
-src/testing/components/affix_fuzzer10.rs linguist-generated=true
-src/testing/components/affix_fuzzer11.rs linguist-generated=true
-src/testing/components/affix_fuzzer12.rs linguist-generated=true
-src/testing/components/affix_fuzzer13.rs linguist-generated=true
-src/testing/components/affix_fuzzer14.rs linguist-generated=true
-src/testing/components/affix_fuzzer15.rs linguist-generated=true
-src/testing/components/affix_fuzzer16.rs linguist-generated=true
-src/testing/components/affix_fuzzer17.rs linguist-generated=true
-src/testing/components/affix_fuzzer18.rs linguist-generated=true
-src/testing/components/affix_fuzzer19.rs linguist-generated=true
-src/testing/components/affix_fuzzer2.rs linguist-generated=true
-src/testing/components/affix_fuzzer20.rs linguist-generated=true
-src/testing/components/affix_fuzzer21.rs linguist-generated=true
-src/testing/components/affix_fuzzer3.rs linguist-generated=true
-src/testing/components/affix_fuzzer4.rs linguist-generated=true
-src/testing/components/affix_fuzzer5.rs linguist-generated=true
-src/testing/components/affix_fuzzer6.rs linguist-generated=true
-src/testing/components/affix_fuzzer7.rs linguist-generated=true
-src/testing/components/affix_fuzzer8.rs linguist-generated=true
-src/testing/components/affix_fuzzer9.rs linguist-generated=true
-src/testing/components/mod.rs linguist-generated=true
-src/testing/datatypes/affix_fuzzer1.rs linguist-generated=true
-src/testing/datatypes/affix_fuzzer2.rs linguist-generated=true
-src/testing/datatypes/affix_fuzzer20.rs linguist-generated=true
-src/testing/datatypes/affix_fuzzer21.rs linguist-generated=true
-src/testing/datatypes/affix_fuzzer3.rs linguist-generated=true
-src/testing/datatypes/affix_fuzzer4.rs linguist-generated=true
-src/testing/datatypes/affix_fuzzer5.rs linguist-generated=true
-src/testing/datatypes/flattened_scalar.rs linguist-generated=true
-src/testing/datatypes/mod.rs linguist-generated=true
-src/testing/datatypes/primitive_component.rs linguist-generated=true
-src/testing/datatypes/string_component.rs linguist-generated=true
diff --git a/crates/store/re_types_blueprint/Cargo.toml b/crates/store/re_types_blueprint/Cargo.toml
deleted file mode 100644
index 2be0628e2c03..000000000000
--- a/crates/store/re_types_blueprint/Cargo.toml
+++ /dev/null
@@ -1,41 +0,0 @@
-[package]
-name = "re_types_blueprint"
-authors.workspace = true
-description = "The core traits and types that power Rerun's Blueprint sub-system."
-edition.workspace = true
-homepage.workspace = true
-include.workspace = true
-license.workspace = true
-publish = true
-readme = "README.md"
-repository.workspace = true
-rust-version.workspace = true
-version.workspace = true
-
-[lints]
-workspace = true
-
-
-[package.metadata.docs.rs]
-all-features = true
-
-
-[features]
-default = []
-
-
-[dependencies]
-# Rerun
-re_tracing.workspace = true
-re_types.workspace = true
-re_types_core.workspace = true
-
-# External
-arrow.workspace = true
-arrow2 = { workspace = true, features = [
- "arrow",
- "compute_concatenate",
- "io_ipc",
- "io_print",
-] }
-once_cell.workspace = true
diff --git a/crates/store/re_types_blueprint/README.md b/crates/store/re_types_blueprint/README.md
deleted file mode 100644
index 64d32d0349d3..000000000000
--- a/crates/store/re_types_blueprint/README.md
+++ /dev/null
@@ -1,10 +0,0 @@
-# re_types_blueprint
-
-Part of the [`rerun`](https://github.com/rerun-io/rerun) family of crates.
-
-[![Latest version](https://img.shields.io/crates/v/re_types.svg)](https://crates.io/crates/re_types)
-[![Documentation](https://docs.rs/re_types/badge.svg)](https://docs.rs/re_types)
-![MIT](https://img.shields.io/badge/license-MIT-blue.svg)
-![Apache](https://img.shields.io/badge/license-Apache-blue.svg)
-
-The core traits and types that power Rerun's Blueprint sub-system.
diff --git a/crates/store/re_types_blueprint/src/blueprint/archetypes/.gitattributes b/crates/store/re_types_blueprint/src/blueprint/archetypes/.gitattributes
deleted file mode 100644
index b89073c8d068..000000000000
--- a/crates/store/re_types_blueprint/src/blueprint/archetypes/.gitattributes
+++ /dev/null
@@ -1,7 +0,0 @@
-# DO NOT EDIT! This file is generated by crates/build/re_types_builder/src/lib.rs
-
-.gitattributes linguist-generated=true
-container_blueprint.rs linguist-generated=true
-mod.rs linguist-generated=true
-panel_blueprint.rs linguist-generated=true
-viewport_blueprint.rs linguist-generated=true
diff --git a/crates/store/re_types_blueprint/src/blueprint/archetypes/mod.rs b/crates/store/re_types_blueprint/src/blueprint/archetypes/mod.rs
deleted file mode 100644
index 45429f55fa41..000000000000
--- a/crates/store/re_types_blueprint/src/blueprint/archetypes/mod.rs
+++ /dev/null
@@ -1,9 +0,0 @@
-// DO NOT EDIT! This file was auto-generated by crates/build/re_types_builder/src/codegen/rust/api.rs
-
-mod container_blueprint;
-mod panel_blueprint;
-mod viewport_blueprint;
-
-pub use self::container_blueprint::ContainerBlueprint;
-pub use self::panel_blueprint::PanelBlueprint;
-pub use self::viewport_blueprint::ViewportBlueprint;
diff --git a/crates/store/re_types_blueprint/src/blueprint/components/.gitattributes b/crates/store/re_types_blueprint/src/blueprint/components/.gitattributes
deleted file mode 100644
index 2978e26ea33d..000000000000
--- a/crates/store/re_types_blueprint/src/blueprint/components/.gitattributes
+++ /dev/null
@@ -1,11 +0,0 @@
-# DO NOT EDIT! This file is generated by crates/build/re_types_builder/src/lib.rs
-
-.gitattributes linguist-generated=true
-auto_layout.rs linguist-generated=true
-auto_views.rs linguist-generated=true
-container_kind.rs linguist-generated=true
-grid_columns.rs linguist-generated=true
-mod.rs linguist-generated=true
-root_container.rs linguist-generated=true
-view_maximized.rs linguist-generated=true
-visualizer_overrides.rs linguist-generated=true
diff --git a/crates/store/re_types_blueprint/src/blueprint/components/mod.rs b/crates/store/re_types_blueprint/src/blueprint/components/mod.rs
deleted file mode 100644
index dfb9de45eef6..000000000000
--- a/crates/store/re_types_blueprint/src/blueprint/components/mod.rs
+++ /dev/null
@@ -1,18 +0,0 @@
-// DO NOT EDIT! This file was auto-generated by crates/build/re_types_builder/src/codegen/rust/api.rs
-
-mod auto_layout;
-mod auto_layout_ext;
-mod auto_views;
-mod container_kind;
-mod grid_columns;
-mod root_container;
-mod view_maximized;
-mod visualizer_overrides;
-
-pub use self::auto_layout::AutoLayout;
-pub use self::auto_views::AutoViews;
-pub use self::container_kind::ContainerKind;
-pub use self::grid_columns::GridColumns;
-pub use self::root_container::RootContainer;
-pub use self::view_maximized::ViewMaximized;
-pub use self::visualizer_overrides::VisualizerOverrides;
diff --git a/crates/store/re_types_blueprint/src/blueprint/datatypes/.gitattributes b/crates/store/re_types_blueprint/src/blueprint/datatypes/.gitattributes
deleted file mode 100644
index c3dfab32d1bc..000000000000
--- a/crates/store/re_types_blueprint/src/blueprint/datatypes/.gitattributes
+++ /dev/null
@@ -1,5 +0,0 @@
-# DO NOT EDIT! This file is generated by crates/build/re_types_builder/src/lib.rs
-
-.gitattributes linguist-generated=true
-mod.rs linguist-generated=true
-utf8list.rs linguist-generated=true
diff --git a/crates/store/re_types_blueprint/src/blueprint/datatypes/mod.rs b/crates/store/re_types_blueprint/src/blueprint/datatypes/mod.rs
deleted file mode 100644
index faad0f80b2d2..000000000000
--- a/crates/store/re_types_blueprint/src/blueprint/datatypes/mod.rs
+++ /dev/null
@@ -1,6 +0,0 @@
-// DO NOT EDIT! This file was auto-generated by crates/build/re_types_builder/src/codegen/rust/api.rs
-
-mod utf8list;
-mod utf8list_ext;
-
-pub use self::utf8list::Utf8List;
diff --git a/crates/store/re_types_blueprint/src/blueprint/mod.rs b/crates/store/re_types_blueprint/src/blueprint/mod.rs
deleted file mode 100644
index e67e9c5c4658..000000000000
--- a/crates/store/re_types_blueprint/src/blueprint/mod.rs
+++ /dev/null
@@ -1,12 +0,0 @@
-pub mod archetypes;
-
-pub mod components {
-
- #[path = "../components/mod.rs"]
- mod _components;
-
- pub use self::_components::*;
- pub use re_types::blueprint::components::*;
-}
-
-pub mod datatypes;
diff --git a/crates/store/re_types_blueprint/src/lib.rs b/crates/store/re_types_blueprint/src/lib.rs
deleted file mode 100644
index 837d8cbc8f0c..000000000000
--- a/crates/store/re_types_blueprint/src/lib.rs
+++ /dev/null
@@ -1,14 +0,0 @@
-//! The core types and traits that power Rerun's Blueprint sub-system.
-
-/// Auto-generated blueprint-related types.
-///
-/// They all implement the [`re_types_core::Component`] trait.
-///
-/// Unstable. Used for the ongoing blueprint experimentation.
-pub mod blueprint;
-
-// TODO(andreas): Workaround for referencing non-blueprint components from blueprint archetypes.
-pub(crate) use re_types::datatypes;
-pub(crate) mod components {
- pub use re_types::components::Name;
-}
diff --git a/crates/store/re_types_core/src/reflection.rs b/crates/store/re_types_core/src/reflection.rs
index 3f57ec665df7..5d1c633b97cf 100644
--- a/crates/store/re_types_core/src/reflection.rs
+++ b/crates/store/re_types_core/src/reflection.rs
@@ -25,7 +25,7 @@ impl Reflection {
///
/// Useful when the only information available is the short name, e.g. when inferring archetype
/// names from an indicator component.
- //TODO( #6889): tagged component will contain a fully qualified archetype name, so this function
+ //TODO(#6889): tagged component will contain a fully qualified archetype name, so this function
// will be unnecessary.
pub fn archetype_reflection_from_short_name(
&self,
diff --git a/crates/viewer/re_component_ui/Cargo.toml b/crates/viewer/re_component_ui/Cargo.toml
index c6a0f3329325..eac5afe72e67 100644
--- a/crates/viewer/re_component_ui/Cargo.toml
+++ b/crates/viewer/re_component_ui/Cargo.toml
@@ -28,7 +28,6 @@ re_tracing.workspace = true
re_types = { workspace = true, features = [
"egui_plot", # Needed to draw marker shapes.
] }
-re_types_blueprint.workspace = true # Needed to give some of the components a custom ui. Could happen in any other crate as well.
re_types_core.workspace = true
re_ui.workspace = true
re_viewer_context.workspace = true
diff --git a/crates/viewer/re_component_ui/src/lib.rs b/crates/viewer/re_component_ui/src/lib.rs
index 5150d8ee061d..bbed24bfd956 100644
--- a/crates/viewer/re_component_ui/src/lib.rs
+++ b/crates/viewer/re_component_ui/src/lib.rs
@@ -34,6 +34,7 @@ use datatype_uis::{
view_view_id,
};
+use re_types::blueprint::components::{RootContainer, ViewMaximized};
use re_types::{
blueprint::components::{
BackgroundKind, Corner2D, Enabled, ForceDistance, ForceIterations, ForceStrength,
@@ -47,7 +48,6 @@ use re_types::{
},
Component as _,
};
-use re_types_blueprint::blueprint::components::{RootContainer, ViewMaximized};
use re_viewer_context::gpu_bridge::colormap_edit_or_view_ui;
/// Default number of ui points to show a number.
diff --git a/crates/viewer/re_selection_panel/Cargo.toml b/crates/viewer/re_selection_panel/Cargo.toml
index be4440087b19..aa09cf939c9a 100644
--- a/crates/viewer/re_selection_panel/Cargo.toml
+++ b/crates/viewer/re_selection_panel/Cargo.toml
@@ -29,7 +29,6 @@ re_log_types.workspace = true
re_log.workspace = true
re_view.workspace = true
re_tracing.workspace = true
-re_types_blueprint.workspace = true # TODO(jleibs): Remove this once VisualizerOverrides is gone
re_types_core.workspace = true
re_types.workspace = true
re_ui.workspace = true
diff --git a/crates/viewer/re_selection_panel/src/visualizer_ui.rs b/crates/viewer/re_selection_panel/src/visualizer_ui.rs
index d1645afff8df..9f10aac8862a 100644
--- a/crates/viewer/re_selection_panel/src/visualizer_ui.rs
+++ b/crates/viewer/re_selection_panel/src/visualizer_ui.rs
@@ -4,8 +4,8 @@ use re_chunk::{ComponentName, RowId, UnitChunkShared};
use re_data_ui::{sorted_component_list_for_ui, DataUi};
use re_entity_db::EntityDb;
use re_log_types::{ComponentPath, EntityPath};
+use re_types::blueprint::components::VisualizerOverrides;
use re_types::external::arrow2;
-use re_types_blueprint::blueprint::components::VisualizerOverrides;
use re_ui::{list_item, UiExt as _};
use re_view::latest_at_with_blueprint_resolved_data;
use re_viewer_context::{
diff --git a/crates/viewer/re_viewer/Cargo.toml b/crates/viewer/re_viewer/Cargo.toml
index 18f55819dca5..ae496fc924a6 100644
--- a/crates/viewer/re_viewer/Cargo.toml
+++ b/crates/viewer/re_viewer/Cargo.toml
@@ -81,7 +81,6 @@ re_view_text_log.workspace = true
re_view_time_series.workspace = true
re_time_panel.workspace = true
re_tracing = { workspace = true, features = ["server"] }
-re_types_blueprint.workspace = true
re_types_core.workspace = true
re_types.workspace = true
re_ui.workspace = true
diff --git a/crates/viewer/re_viewer/src/blueprint/validation_gen/mod.rs b/crates/viewer/re_viewer/src/blueprint/validation_gen/mod.rs
index bed35cf8a280..d38838f0f70c 100644
--- a/crates/viewer/re_viewer/src/blueprint/validation_gen/mod.rs
+++ b/crates/viewer/re_viewer/src/blueprint/validation_gen/mod.rs
@@ -3,9 +3,12 @@ use super::validation::validate_component;
use re_entity_db::EntityDb;
pub use re_types::blueprint::components::ActiveTab;
pub use re_types::blueprint::components::ApplyLatestAt;
+pub use re_types::blueprint::components::AutoLayout;
+pub use re_types::blueprint::components::AutoViews;
pub use re_types::blueprint::components::BackgroundKind;
pub use re_types::blueprint::components::ColumnShare;
pub use re_types::blueprint::components::ComponentColumnSelector;
+pub use re_types::blueprint::components::ContainerKind;
pub use re_types::blueprint::components::Corner2D;
pub use re_types::blueprint::components::Enabled;
pub use re_types::blueprint::components::FilterByRange;
@@ -13,6 +16,7 @@ pub use re_types::blueprint::components::FilterIsNotNull;
pub use re_types::blueprint::components::ForceDistance;
pub use re_types::blueprint::components::ForceIterations;
pub use re_types::blueprint::components::ForceStrength;
+pub use re_types::blueprint::components::GridColumns;
pub use re_types::blueprint::components::GridSpacing;
pub use re_types::blueprint::components::IncludedContent;
pub use re_types::blueprint::components::Interactive;
@@ -21,25 +25,21 @@ pub use re_types::blueprint::components::MapProvider;
pub use re_types::blueprint::components::NearClipPlane;
pub use re_types::blueprint::components::PanelState;
pub use re_types::blueprint::components::QueryExpression;
+pub use re_types::blueprint::components::RootContainer;
pub use re_types::blueprint::components::RowShare;
pub use re_types::blueprint::components::SelectedColumns;
pub use re_types::blueprint::components::TensorDimensionIndexSlider;
pub use re_types::blueprint::components::TimelineName;
pub use re_types::blueprint::components::ViewClass;
pub use re_types::blueprint::components::ViewFit;
+pub use re_types::blueprint::components::ViewMaximized;
pub use re_types::blueprint::components::ViewOrigin;
pub use re_types::blueprint::components::ViewerRecommendationHash;
pub use re_types::blueprint::components::Visible;
pub use re_types::blueprint::components::VisibleTimeRange;
pub use re_types::blueprint::components::VisualBounds2D;
+pub use re_types::blueprint::components::VisualizerOverrides;
pub use re_types::blueprint::components::ZoomLevel;
-pub use re_types_blueprint::blueprint::components::AutoLayout;
-pub use re_types_blueprint::blueprint::components::AutoViews;
-pub use re_types_blueprint::blueprint::components::ContainerKind;
-pub use re_types_blueprint::blueprint::components::GridColumns;
-pub use re_types_blueprint::blueprint::components::RootContainer;
-pub use re_types_blueprint::blueprint::components::ViewMaximized;
-pub use re_types_blueprint::blueprint::components::VisualizerOverrides;
/// Because blueprints are both read and written the schema must match what
/// we expect to find or else we will run into all kinds of problems.
diff --git a/crates/viewer/re_viewer/src/reflection/mod.rs b/crates/viewer/re_viewer/src/reflection/mod.rs
index de51ce63624a..078c12c34885 100644
--- a/crates/viewer/re_viewer/src/reflection/mod.rs
+++ b/crates/viewer/re_viewer/src/reflection/mod.rs
@@ -5,7 +5,6 @@
#![allow(unused_imports)]
use re_types::blueprint::components::*;
use re_types::components::*;
-use re_types_blueprint::blueprint::components::*;
use re_types_core::components::*;
use re_types_core::{
reflection::{
@@ -2145,7 +2144,8 @@ fn generate_archetype_reflection() -> ArchetypeReflectionMap {
fields: vec![
ArchetypeFieldReflection { component_name :
"rerun.blueprint.components.PanelState".into(), display_name :
- "State", docstring_md : "", is_required : false, },
+ "State", docstring_md : "Current state of the panels.", is_required :
+ false, },
],
},
),
diff --git a/crates/viewer/re_viewport/Cargo.toml b/crates/viewer/re_viewport/Cargo.toml
index af5a315504a9..fe80f4c3b184 100644
--- a/crates/viewer/re_viewport/Cargo.toml
+++ b/crates/viewer/re_viewport/Cargo.toml
@@ -32,7 +32,6 @@ re_renderer = { workspace = true, default-features = false, features = [
re_view.workspace = true
re_tracing.workspace = true
re_types.workspace = true
-re_types_blueprint.workspace = true
re_ui.workspace = true
re_viewer_context.workspace = true
re_viewport_blueprint.workspace = true
diff --git a/crates/viewer/re_viewport/src/lib.rs b/crates/viewer/re_viewport/src/lib.rs
index d69e424ae48f..5d1449a06318 100644
--- a/crates/viewer/re_viewport/src/lib.rs
+++ b/crates/viewer/re_viewport/src/lib.rs
@@ -13,6 +13,6 @@ mod viewport_ui;
pub use self::viewport_ui::ViewportUi;
pub mod external {
- pub use re_types_blueprint;
+ pub use re_types;
pub use re_view;
}
diff --git a/crates/viewer/re_viewport_blueprint/Cargo.toml b/crates/viewer/re_viewport_blueprint/Cargo.toml
index 368b1db6acc8..e4a982608ae9 100644
--- a/crates/viewer/re_viewport_blueprint/Cargo.toml
+++ b/crates/viewer/re_viewport_blueprint/Cargo.toml
@@ -25,7 +25,6 @@ re_entity_db.workspace = true
re_log.workspace = true
re_log_types.workspace = true
re_tracing.workspace = true
-re_types_blueprint.workspace = true
re_types_core.workspace = true
re_types.workspace = true
re_ui.workspace = true
diff --git a/crates/viewer/re_viewport_blueprint/src/view_contents.rs b/crates/viewer/re_viewport_blueprint/src/view_contents.rs
index 2351767c15da..ef4079f1f515 100644
--- a/crates/viewer/re_viewport_blueprint/src/view_contents.rs
+++ b/crates/viewer/re_viewport_blueprint/src/view_contents.rs
@@ -6,6 +6,7 @@ use re_entity_db::{external::re_chunk_store::LatestAtQuery, EntityDb, EntityTree
use re_log_types::{
path::RuleEffect, EntityPath, EntityPathFilter, EntityPathRule, EntityPathSubs, Timeline,
};
+use re_types::blueprint::components::VisualizerOverrides;
use re_types::{
blueprint::{
archetypes as blueprint_archetypes, components as blueprint_components,
@@ -13,7 +14,6 @@ use re_types::{
},
Archetype as _, ViewClassIdentifier,
};
-use re_types_blueprint::blueprint::components::VisualizerOverrides;
use re_types_core::ComponentName;
use re_viewer_context::{
ApplicableEntities, DataQueryResult, DataResult, DataResultHandle, DataResultNode,
diff --git a/crates/viewer/re_viewport_blueprint/src/viewport_blueprint.rs b/crates/viewer/re_viewport_blueprint/src/viewport_blueprint.rs
index 911e53bc3956..f26dc39cda30 100644
--- a/crates/viewer/re_viewport_blueprint/src/viewport_blueprint.rs
+++ b/crates/viewer/re_viewport_blueprint/src/viewport_blueprint.rs
@@ -14,13 +14,13 @@ use smallvec::SmallVec;
use re_chunk_store::LatestAtQuery;
use re_entity_db::EntityPath;
-use re_types::{
- blueprint::components::ViewerRecommendationHash, Archetype as _, ViewClassIdentifier,
-};
-use re_types_blueprint::blueprint::{
+use re_types::blueprint::{
archetypes as blueprint_archetypes,
components::{AutoLayout, AutoViews, RootContainer, ViewMaximized},
};
+use re_types::{
+ blueprint::components::ViewerRecommendationHash, Archetype as _, ViewClassIdentifier,
+};
use re_viewer_context::{
blueprint_id_to_tile_id, ContainerId, Contents, Item, ViewId, ViewerContext,
};
diff --git a/rerun_cpp/src/rerun/blueprint/archetypes/panel_blueprint.hpp b/rerun_cpp/src/rerun/blueprint/archetypes/panel_blueprint.hpp
index 7f3f44c62d4e..79c674928cfa 100644
--- a/rerun_cpp/src/rerun/blueprint/archetypes/panel_blueprint.hpp
+++ b/rerun_cpp/src/rerun/blueprint/archetypes/panel_blueprint.hpp
@@ -18,6 +18,7 @@
namespace rerun::blueprint::archetypes {
/// **Archetype**: Shared state for the 3 collapsible panels.
struct PanelBlueprint {
+ /// Current state of the panels.
std::optional state;
public:
@@ -31,6 +32,7 @@ namespace rerun::blueprint::archetypes {
PanelBlueprint() = default;
PanelBlueprint(PanelBlueprint&& other) = default;
+ /// Current state of the panels.
PanelBlueprint with_state(rerun::blueprint::components::PanelState _state) && {
state = std::move(_state);
// See: https://github.com/rerun-io/rerun/issues/4027
diff --git a/crates/viewer/re_viewport_blueprint/src/container.rs b/crates/viewer/re_viewport_blueprint/src/container.rs
index 85cc1d7ee065..af0b03fb810f 100644
--- a/crates/viewer/re_viewport_blueprint/src/container.rs
+++ b/crates/viewer/re_viewport_blueprint/src/container.rs
@@ -4,13 +4,13 @@ use egui_tiles::TileId;
use re_chunk::LatestAtQuery;
use re_entity_db::EntityDb;
use re_log_types::EntityPath;
+use re_types::blueprint::archetypes as blueprint_archetypes;
+use re_types::blueprint::components::{ContainerKind, GridColumns};
use re_types::components::Name;
use re_types::{blueprint::components::Visible, Archetype as _};
-use re_types_blueprint::blueprint::archetypes as blueprint_archetypes;
-use re_types_blueprint::blueprint::components::{ContainerKind, GridColumns};
use re_viewer_context::{ContainerId, Contents, ContentsName, ViewId, ViewerContext};
/// The native version of a [`re_types_blueprint::blueprint::archetypes::ContainerBlueprint`].
///
/// This represents a single container in the blueprint. On each frame, it is
/// used to populate an [`egui_tiles::Container`]. Each child in `contents` can
@@ -180,12 +180,11 @@ impl ContainerBlueprint {
let contents: Vec<_> = contents.iter().map(|item| item.as_entity_path()).collect();
let container_kind = crate::container_kind_from_egui(*container_kind);
- let mut arch =
- re_types_blueprint::blueprint::archetypes::ContainerBlueprint::new(container_kind)
- .with_contents(&contents)
- .with_col_shares(col_shares.clone())
- .with_row_shares(row_shares.clone())
- .with_visible(*visible);
+ let mut arch = re_types::blueprint::archetypes::ContainerBlueprint::new(container_kind)
+ .with_contents(&contents)
+ .with_col_shares(col_shares.clone())
+ .with_row_shares(row_shares.clone())
+ .with_visible(*visible);
// Note: it's important to _not_ clear the `Name` component if `display_name` is set to
// `None`, as we call this function with `ContainerBlueprint` recreated from `egui_tiles`,
@@ -4,13 +4,13 @@ use egui_tiles::TileId;
use re_viewer_context::{ContainerId, Contents, ContentsName, ViewId, ViewerContext};
-/// The native version of a [`re_types_blueprint::blueprint::archetypes::ContainerBlueprint`].
+/// The native version of a [`re_types::blueprint::archetypes::ContainerBlueprint`].
///
/// This represents a single container in the blueprint. On each frame, it is
diff --git a/crates/viewer/re_viewport_blueprint/src/lib.rs b/crates/viewer/re_viewport_blueprint/src/lib.rs
index 3ec02beb7356..5ed6164daf1c 100644
--- a/crates/viewer/re_viewport_blueprint/src/lib.rs
+++ b/crates/viewer/re_viewport_blueprint/src/lib.rs
@@ -21,15 +21,15 @@ pub use viewport_command::ViewportCommand;
/// The entity path of the viewport blueprint in the blueprint store.
pub const VIEWPORT_PATH: &str = "viewport";
-/// Converts a [`re_types_blueprint::blueprint::components::ContainerKind`] into a [`egui_tiles::ContainerKind`].
+/// Converts a [`re_types::blueprint::components::ContainerKind`] into a [`egui_tiles::ContainerKind`].
///
/// Does not implement the `From`/`To` traits because we don't want `re_types_blueprint` to depend
/// on `egui`, and we cannot do it from here because of orphan rules.
#[inline]
pub fn container_kind_to_egui(
- kind: re_types_blueprint::blueprint::components::ContainerKind,
+ kind: re_types::blueprint::components::ContainerKind,
) -> egui_tiles::ContainerKind {
- use re_types_blueprint::blueprint::components::ContainerKind;
+ use re_types::blueprint::components::ContainerKind;
match kind {
ContainerKind::Tabs => egui_tiles::ContainerKind::Tabs,
ContainerKind::Horizontal => egui_tiles::ContainerKind::Horizontal,
@@ -38,15 +38,15 @@ pub fn container_kind_to_egui(
}
}
-/// Converts a [`egui_tiles::ContainerKind`] into a [`re_types_blueprint::blueprint::components::ContainerKind`].
+/// Converts a [`egui_tiles::ContainerKind`] into a [`re_types::blueprint::components::ContainerKind`].
///
/// Does not implement the `From`/`To` traits because we don't want `re_types_blueprint` to depend
/// on `egui`, and we cannot do it from here because of orphan rules.
#[inline]
pub fn container_kind_from_egui(
kind: egui_tiles::ContainerKind,
-) -> re_types_blueprint::blueprint::components::ContainerKind {
- use re_types_blueprint::blueprint::components::ContainerKind;
+) -> re_types::blueprint::components::ContainerKind {
+ use re_types::blueprint::components::ContainerKind;
match kind {
egui_tiles::ContainerKind::Tabs => ContainerKind::Tabs,
egui_tiles::ContainerKind::Horizontal => ContainerKind::Horizontal,
@@ -21,15 +21,15 @@ pub use viewport_command::ViewportCommand;
///
-/// Does not implement the `From`/`To` traits because we don't want `re_types_blueprint` to depend
+/// Does not implement the `From`/`To` traits because we don't want `re_types` to depend
/// on `egui`, and we cannot do it from here because of orphan rules.
#[inline]
@@ -38,15 +38,15 @@ pub fn container_kind_to_egui(
///
-/// Does not implement the `From`/`To` traits because we don't want `re_types_blueprint` to depend
+/// Does not implement the `From`/`To` traits because we don't want `re_types` to depend
/// on `egui`, and we cannot do it from here because of orphan rules.
#[inline]
diff --git a/rerun_py/rerun_sdk/rerun/blueprint/archetypes/panel_blueprint.py b/rerun_py/rerun_sdk/rerun/blueprint/archetypes/panel_blueprint.py
index 97aa8fc0744a..e9554a2d2053 100644
--- a/rerun_py/rerun_sdk/rerun/blueprint/archetypes/panel_blueprint.py
+++ b/rerun_py/rerun_sdk/rerun/blueprint/archetypes/panel_blueprint.py
@@ -23,7 +23,15 @@ class PanelBlueprint(Archetype):
"""**Archetype**: Shared state for the 3 collapsible panels."""
def __init__(self: Any, *, state: blueprint_components.PanelStateLike | None = None):
- """Create a new instance of the PanelBlueprint archetype."""
+ """
+ Create a new instance of the PanelBlueprint archetype.
+
+ Parameters
+ ----------
+ state:
+ Current state of the panels.
+
+ """
# You can define your own __init__ function as a member of PanelBlueprintExt in panel_blueprint_ext.py
with catch_and_log_exceptions(context=self.__class__.__name__):
@@ -49,5 +57,9 @@ def _clear(cls) -> PanelBlueprint:
default=None,
converter=blueprint_components.PanelStateBatch._optional, # type: ignore[misc]
)
+ # Current state of the panels.
+ #
+ # (Docstring intentionally commented out to hide this field from the docs)
+
__str__ = Archetype.__str__
__repr__ = Archetype.__repr__ # type: ignore[assignment]